/* --COPYRIGHT--,BSD
 * Copyright (c) $(CPYYEAR), Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--
 */
/*
 *  ======== main_BIOS.c ========
 */

#include <xdc/std.h>
#include <xdc/runtime/Diags.h>
#include <stdlib.h>
#include <ti/sysbios/BIOS.h>

#include <ti/sdo/fc/global/FCSettings.h>

/* IRES resources */
#include <ti/sdo/fc/ires/hdvicp/iresman_hdvicp.h>
#include <ti/sdo/fc/ires/hdvicp/ires_hdvicp2.h>

/* This file is required to be able to configure this resource manager */
#include <ti/sdo/fc/ires/hdvicp/hdvicp2.h>

/* For the log statement */
#include <xdc/runtime/Log.h>

/* To configure DSKT2 */
#include <ti/sdo/fc/dskt2/dskt2.h>
#include <xdc/runtime/IHeap.h>
extern xdc_runtime_IHeap_Handle EXT_HEAP;

/* Initialize RMAN  */
#include <ti/sdo/fc/rman/rman.h>

/* #define MOD_NAME "ti.sdo.fc.rman"*/
#define MODNAME "*"

/* Declare  the functions used to configure HDVICP2 */
extern Void _configure(IALG_Handle algHandle, IRES_HDVICP2_Obj * hdvicpHandle,
        IRES_HDVICP2_CallbackFxn cbFunctionPtr, Void * cbArgs);

extern Void _wait(IALG_Handle algHandle, IRES_HDVICP2_Obj * hdvicpHandle,
        IRES_YieldContext * yieldContext);

extern Void _done(IALG_Handle algHandle, IRES_HDVICP2_Obj * hdvicpHandle);

/*
 *  ======== main ========
 */
/* ARGSUSED */
Void main(Int argc, Char * argv[])
{

    IRESMAN_HdVicpParams params;

    /* Set default mask for FC modules */
    FCSettings_init();
    Diags_setMask(FCSETTINGS_MODNAME"+467");

    /* Configure DSKT2 heaps and scratch */
    DSKT2_daram0Heap = EXT_HEAP;
    DSKT2_daram1Heap = EXT_HEAP;
    DSKT2_daram2Heap = EXT_HEAP;

    DSKT2_saram0Heap = EXT_HEAP;
    DSKT2_saram1Heap = EXT_HEAP;
    DSKT2_saram2Heap = EXT_HEAP;

    DSKT2_esdataHeap = EXT_HEAP;
    DSKT2_iprogHeap = EXT_HEAP;
    DSKT2_eprogHeap = EXT_HEAP;

    _DSKT2_heap = EXT_HEAP;

    /* Can configure RMAN here if required */
	
	/* Need to configure IRES HDVICP */
    _HDVICP2_NUMRESOURCES = 1;	

    ti_sdo_fc_ires_hdvicp_HDVICP2_interrupts[0] = 38;
    HDVICP2_PARAMS.memoryBaseAddress[0] = 0x58000000;        
	HDVICP2_PARAMS.configFxn = (ConfigFxn) &_configure;  
    HDVICP2_PARAMS.waitFxn  = (WaitFxn) &_wait; 
    HDVICP2_PARAMS.doneFxn  = (DoneFxn) &_done; 
    HDVICP2_PARAMS.resetFxn = ti_sdo_fc_ires_hdvicp_HDVICP2_reset_Netra;
    /* Might want to configure other parameters from 
       ti/sdo/fc/ires/hdvicp/hdvicp2.h, such as:
       HDVICP2_PARAMS.resetControlAddr[0] or 
       HDVICP2_PARAMS.registerBaseAddress[0`] 
     */

    /* Set up RMAN for use */
    if (IRES_OK != RMAN_init()) {
        exit (0); 
    }
    
    params.numResources = 1;
    params.baseConfig.size = sizeof(IRESMAN_HdVicpParams);
    params.baseConfig.allocFxn = &DSKT2_allocPersistent;
    params.baseConfig.freeFxn = &DSKT2_freePersistent;

    if (IRES_OK != RMAN_register((IRESMAN_Fxns *)&IRESMAN_HDVICP, 
            (IRESMAN_Params *)&params)) {
        exit (0);
    }
    
    Log_print0(Diags_EXIT, "[+X] main> Exit");

    BIOS_start();
}
